@@ -15,7 +15,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
     ListHumanLoopsResponseTypeDef,
@@ -43,7 +43,7 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         CreationTimeBefore: datetime = None,
         SortOrder: Literal["Ascending", "Descending"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListHumanLoopsResponseTypeDef, None, None]:
+    ) -> Iterator[ListHumanLoopsResponseTypeDef]:
         """
         [ListHumanLoops.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         """
